==> any-signal-4.0.0.tgz: package/README.md <==
# any-signal

[![Build Status](https://github.com/jacobheun/any-signal/actions/workflows/node.js.yml/badge.svg?branch=master)](https://travis-ci.org/jacobheun/any-signal) [![JavaScript Style Guide](https://img.shields.io/badge/code_style-standard-brightgreen.svg)](https://standardjs.com)

> Combines an array of AbortSignals into a single signal that is aborted when any signal is.

## Install

```
npm install any-signal
```

## Usage

```js
const anySignal = require('any-signal')

const userController = new AbortController()
const timeoutController = new AbortController()

const combinedSignal = anySignal([userController.signal, timeoutController.signal])
combinedSignal.addEventListener('abort', () => console.log('Abort!'))

// Abort after 1 second
const timeoutId = setTimeout(() => timeoutController.abort(), 1000)

// The user or the timeout can now abort the action
await performSomeAction({ signal: combinedSignal })
clearTimeout(timeoutId)

// Clear will clean up internal event handlers
combinedSignal.clear()
```

## API

### `anySignal(signals)`

#### Parameters

| Name | Type | Description |
|------|------|-------------|
| signals | Array<[`AbortSignal`](https://developer.mozilla.org/en-US/docs/Web/API/AbortSignal)> | The Signals that will be observed and mapped to the returned Signal |

#### Returns

| Type | Description |
|------|-------------|
| `ClearableSignal`](https://developer.mozilla.org/en-US/docs/Web/API/AbortSignal) | A Signal that will be aborted as soon as any one of its parent signals are aborted. Extends AbortSignal with the `clear` function for cleanup |

The returned [`ClearableSignal`](https://developer.mozilla.org/en-US/docs/Web/API/AbortSignal) will only be aborted once, and as soon as one of its parent signals is aborted.

### `ClearableSignal.clear()`
Removes all internal event handlers. This **must** be called after abort has been called, or the signals have successfully executed, otherwise there is a risk of leaking event handlers.

## Acknowledgements

The anySignal function is taken from a [comment by jakearchibald](https://github.com/whatwg/fetch/issues/905#issuecomment-491970649)

## LICENSE

[MIT](LICENSE) © Jacob Heun

==> any-signal-4.0.1.tgz: package/README.md <==
# any-signal

[![Build Status](https://github.com/jacobheun/any-signal/actions/workflows/node.js.yml/badge.svg?branch=master)](https://travis-ci.org/jacobheun/any-signal) [![JavaScript Style Guide](https://img.shields.io/badge/code_style-standard-brightgreen.svg)](https://standardjs.com)

> Combines an array of AbortSignals into a single signal that is aborted when any signal is.

## Install

```
npm install any-signal
```

## Usage

```js
const anySignal = require('any-signal')

const userController = new AbortController()
const timeoutController = new AbortController()

const combinedSignal = anySignal([userController.signal, timeoutController.signal])
combinedSignal.addEventListener('abort', () => console.log('Abort!'))

// Abort after 1 second
const timeoutId = setTimeout(() => timeoutController.abort(), 1000)

// The user or the timeout can now abort the action
await performSomeAction({ signal: combinedSignal })
clearTimeout(timeoutId)

// Clear will clean up internal event handlers
combinedSignal.clear()
```

## API

### `anySignal(signals)`

#### Parameters

| Name | Type | Description |
|------|------|-------------|
| signals | Array<[`AbortSignal`](https://developer.mozilla.org/en-US/docs/Web/API/AbortSignal)> | The Signals that will be observed and mapped to the returned Signal |

#### Returns

| Type | Description |
|------|-------------|
| [`ClearableSignal`](https://developer.mozilla.org/en-US/docs/Web/API/AbortSignal) | A Signal that will be aborted as soon as any one of its parent signals are aborted. Extends AbortSignal with the `clear` function for cleanup |

The returned [`ClearableSignal`](https://developer.mozilla.org/en-US/docs/Web/API/AbortSignal) will only be aborted once, and as soon as one of its parent signals is aborted.

### `ClearableSignal.clear()`
Removes all internal event handlers. This **must** be called after abort has been called, or the signals have successfully executed, otherwise there is a risk of leaking event handlers.

## Acknowledgements

The anySignal function is taken from a [comment by jakearchibald](https://github.com/whatwg/fetch/issues/905#issuecomment-491970649)

## LICENSE

[MIT](LICENSE) © Jacob Heun
